@@ -12,7 +12,11 @@ class Migration(migrations.Migration):
     ]
 
     operations = [
-        migrations.AlterField(
+        migrations.RemoveField(
+            model_name='theme',
+            name='related_modal_background_opacity'
+        ),
+        migrations.AddField(
             model_name='theme',
             name='related_modal_background_opacity',
             field=models.CharField(
